@@ -1,12 +1,12 @@
 from .colorbutton import ColorButton
 # from color_duo
 # from equalizer
-from .equalizer_bar import Equalizer
+from .equalizer_bar import EqualizerBar
 # from filebrowser
 from .gradient import Gradient
 from .paint import Paint
 from .passwordedit import PasswordEdit
 from .power_bar import PowerBar
-from .palette import Palette
+from .palette import PaletteGrid, PaletteHorizontal, PaletteVertical
 # from scrubber
 # from stopwatch
