@@ -3,11 +3,13 @@ if 'PyQt5' in sys.modules:
     from PyQt5 import QtCore, QtGui, QtWidgets
     from PyQt5.QtCore import Qt
     from PyQt5.QtCore import pyqtSignal as Signal
+    from . import resources_pyqt5
 
 else:
     from PySide2 import QtCore, QtGui, QtWidgets
     from PySide2.QtCore import Qt
     from PySide2.QtCore import Signal
+    from . import resources_pyside2
 
 
 class PasswordEdit(QtWidgets.QLineEdit):
@@ -18,8 +20,8 @@ class PasswordEdit(QtWidgets.QLineEdit):
     def __init__(self, show_visibility=True, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-        self.visibleIcon = QtGui.QIcon("eye.svg")
-        self.hiddenIcon = QtGui.QIcon("hidden.svg")
+        self.visibleIcon = QtGui.QIcon(":/icons/eye.svg")
+        self.hiddenIcon = QtGui.QIcon(":/icons/hidden.svg")
 
         self.setEchoMode(QtWidgets.QLineEdit.Password)
         
